@@ -9,7 +9,7 @@
 #
 package Test::Moose::More::Utils;
 our $AUTHORITY = 'cpan:RSRCHBOY';
-$Test::Moose::More::Utils::VERSION = '0.043';
+$Test::Moose::More::Utils::VERSION = '0.045';
 # ABSTRACT: Various utility functions for TMM (and maybe others!)
 
 use strict;
@@ -66,15 +66,13 @@ __END__
 
 =for :stopwords Chris Weyl Chad Etheridge Granum Karen TMM
 
-=for :stopwords Wishlist flattr flattr'ed gittip gittip'ed
-
 =head1 NAME
 
 Test::Moose::More::Utils - Various utility functions for TMM (and maybe others!)
 
 =head1 VERSION
 
-This document describes version 0.043 of Test::Moose::More::Utils - released February 14, 2017 as part of Test-Moose-More.
+This document describes version 0.045 of Test::Moose::More::Utils - released March 24, 2017 as part of Test-Moose-More.
 
 =head1 FUNCTIONS
 
@@ -119,25 +117,6 @@ feature.
 
 Chris Weyl <cweyl@alumni.drew.edu>
 
-=head2 I'm a material boy in a material world
-
-=begin html
-
-<a href="https://gratipay.com/RsrchBoy/"><img src="http://img.shields.io/gratipay/RsrchBoy.svg" /></a>
-<a href="http://bit.ly/rsrchboys-wishlist"><img src="http://wps.io/wp-content/uploads/2014/05/amazon_wishlist.resized.png" /></a>
-<a href="https://flattr.com/submit/auto?user_id=RsrchBoy&url=https%3A%2F%2Fgithub.com%2FRsrchBoy%2FTest-Moose-More&title=RsrchBoy's%20CPAN%20Test-Moose-More&tags=%22RsrchBoy's%20Test-Moose-More%20in%20the%20CPAN%22"><img src="http://api.flattr.com/button/flattr-badge-large.png" /></a>
-
-=end html
-
-Please note B<I do not expect to be gittip'ed or flattr'ed for this work>,
-rather B<it is simply a very pleasant surprise>. I largely create and release
-works like this because I need them or I find it enjoyable; however, don't let
-that stop you if you feel like it ;)
-
-L<Flattr|https://flattr.com/submit/auto?user_id=RsrchBoy&url=https%3A%2F%2Fgithub.com%2FRsrchBoy%2FTest-Moose-More&title=RsrchBoy's%20CPAN%20Test-Moose-More&tags=%22RsrchBoy's%20Test-Moose-More%20in%20the%20CPAN%22>,
-L<Gratipay|https://gratipay.com/RsrchBoy/>, or indulge my
-L<Amazon Wishlist|http://bit.ly/rsrchboys-wishlist>...  If and *only* if you so desire.
-
 =head1 COPYRIGHT AND LICENSE
 
 This software is Copyright (c) 2012 by Chris Weyl.
